@@ -143,13 +143,13 @@ class SubTechnique:
                 "datasources": [datasource.name for datasource in self.datasources]
             }
         except Exception as e:
-            logging.error('Failed to jsonify object, error was: {}'.format(e))
-            raise enterpriseattack.Error('Failed to create json object, error was: {}'.format(e))
+            logging.error(f'Failed to jsonify object, error was: {e}')
+            raise enterpriseattack.Error(f'Failed to create json object, error was: {e}')
     
     #---------------------------------------------------------------------------------#
     
     def __str__(self):
-        return '{} Mitre Att&ck Sub Technique'.format(self.name)
+        return f'{self.name} Mitre Att&ck Sub Technique'
     
     def __repr__(self):
-        return '{} {}'.format(self.__class__, self.name)
+        return f'{self.__class__} {self.name}'
