@@ -148,13 +148,13 @@ class Technique:
                 "kill_chain_phases": self.kill_chain_phases
             }
         except Exception as e:
-            logging.error('Failed to jsonify object, error was: {}'.format(e))
-            raise enterpriseattack.Error('Failed to create json object, error was: {}'.format(e))
+            logging.error(f'Failed to jsonify object, error was: {e}')
+            raise enterpriseattack.Error(f'Failed to create json object, error was: {e}')
 
     #---------------------------------------------------------------------------------#
     
     def __str__(self):
-        return '{} Mitre Att&ck Technique'.format(self.name)
+        return f'{self.name} Mitre Att&ck Technique'
     
     def __repr__(self):
-        return '{} {}'.format(self.__class__, self.name)
\ No newline at end of file
+        return f'{self.__class__} {self.name}'
\ No newline at end of file
